#
# spec file for package solaar
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 160000
%global pythons python311
%else
%global pythons python3
%endif

Name:           solaar
Version:        1.1.14
Release:        1.3
Summary:        Linux devices manager for the Logitech Unifying Receiver
License:        GPL-2.0-or-later
Group:          Hardware/Other
URL:            https://pwr-solaar.github.io/Solaar
Source0:        Solaar-%{version}.tar.gz
#PATCH-FIX-OPENSUSE solaar-fix-desktop-categories.patch malcolmlewis@opensuse.org -- Fix desktop categories as per openSUSE desktop file specification.
Patch0:         solaar-fix-desktop-categories.patch
#
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module dbus-python}
BuildRequires:  %{python_module evdev}
BuildRequires:  %{python_module gobject-Gdk}
BuildRequires:  %{python_module gobject}
BuildRequires:  %{python_module hid-parser}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-xlib}
BuildRequires:  %{python_module pyudev}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing_extensions}
#
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  typelib-1_0-Gtk-3_0
#
Requires:       python3-PyYAML
Requires:       python3-dbus-python
Requires:       python3-evdev
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-hid-parser
Requires:       python3-psutil
Requires:       python3-pyudev
Requires:       python3-typing_extensions
#
Requires:       solaar-udev >= %{version}
Requires:       typelib(AyatanaAppIndicator3)
Requires:       typelib(Gtk) >= 3.0
#
Recommends:     python3-python-xlib
#
Obsoletes:      solaar-cli < %{version}
Provides:       solaar-cli = %{version}
#
BuildArch:      noarch

%description
Solaar will detect all devices paired with your Unifying Receiver, and
at the very least display some basic information about them.

For some devices, extra settings (usually not available through the
standard Linux system configuration) are supported. For a full list of
supported devices and their features, see docs/devices.md.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/Other

%description    doc
Solaar will detect all devices paired with your Unifying Receiver, and
at the very least display some basic information about them.

For some devices, extra settings (usually not available through the
standard Linux system configuration) are supported. For a full list of
supported devices and their features, see docs/devices.md.

%package        udev
Summary:        Udev rules for accessing Logitech Unifying Receiver
Group:          Hardware/Other
Requires:       udev
Conflicts:      solaar-cli < %{version}

%description    udev
Rules that users are able to access Logitech Unifying Receiver.

%prep
%autosetup -p1 -n Solaar-%{version}

# Fix desktop file installation
sed -i '/yield autostart_path/d' setup.py

%build
sed -i 's#%{_bindir}/env python##' lib/solaar/gtk.py lib/solaar/tasks.py
%python_build

%install
%python_install

%fdupes %{buildroot}%{python_sitelib}
%fdupes -s %{buildroot}%{_datadir}

install -d 0755 %{buildroot}%{_udevrulesdir}
install -m 0644 rules.d/42-logitech-unify-permissions.rules %{buildroot}%{_udevrulesdir}/42-logitech-unify-permissions.rules

ln -s solaar %{buildroot}%{_bindir}/solaar-cli

# We use the system package
rm -rf %{buildroot}%{python3_sitelib}/hid_parser
# We do not need generate keysymdef.py
rm -f %{buildroot}%{python3_sitelib}/keysyms/__pycache__/generate*.pyc
rm -f %{buildroot}%{python3_sitelib}/keysyms/generate.py

%check
%pytest

%posttrans udev
# This is needed to apply permissions to existing devices when the package is
# installed.
%{_bindir}/udevadm trigger --subsystem-match=hidraw --action=add

%files
%doc CHANGELOG.md COPYRIGHT README.md Release_Notes.md
%license LICENSE.txt
%{_bindir}/%{name}
%{_bindir}/%{name}-cli
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/32x32/apps/solaar-*.png
%{_datadir}/icons/hicolor/scalable/apps/solaar*.svg
%{_datadir}/metainfo/io.github.pwr_solaar.solaar.metainfo.xml
%{python_sitelib}/hidapi
%{python_sitelib}/logitech_receiver
%{python_sitelib}/keysyms
%{python_sitelib}/solaar
%{python_sitelib}/solaar-*

%files udev
%{_udevrulesdir}/42-logitech-unify-permissions.rules

%files doc
%doc docs/*

%changelog
* Wed Jan  1 2025 asn@cryptomilk.org
- Update to version 1.1.14:
  * release 1.1.14
  * i18n: Swedish translations in .desktop files
  * release 1.1.14rc4
  * cli: handle fake feature enums in show
  * Update Polish translation
  * release 1.1.14rc3
  * Fix battery entry in device
  * release 1.1.14rc2
  * release 1.1.14rc1
  * i18n: Swedish translations in .desktop files
  * Update Swedish translation
  * i18n: Swedish translations in .desktop files
  * po: Add translator to list (#2687)
  * po: Update tr.po (#2683)
  * settings: Add ratchet setting for smart shift enhanced devices (#2681)
  * receiver: fix BoltReceiver, Ex100Receiver __init__ (#2661)
  * po: Update Swedish translation (#2671)
  * po: Update Swedish translation (#2670)
  * hidpp20_constants: Refactor Gesture into enum
  * refactor: replace ERROR NamedInts by IntEnum (#2645)
  * Refactor: hidpp20  to use enum (#2647)
  * i18n: Updated Norwegian Nynorsk (nn) (#2655)
  * i18n: Updated Norwegian Bokmål (nb)
  * i18n: Updated Norwegian Bokmål (nb)
  * refactor: use IntEnum for firmware and cidgroup constances
  * change pairing error values to intenums
  * ui: fix initialization bug for PackedRangeControl
  * notifications: Introduce unit tests
  * Refactor: Introduce Feature enum
  * Test Feature class
  * Test and refactor process_notification
  * Test key_is_down
  * settings: check all bits for extended report rate
  * Fix copy-paste error while refactoring notifications.py
  * RuleComponentUI: Type hints methods
  * diversion_rules: Add type hints
  * Fix signature of show
  * Action menu: Move context menu into own class
  * Fix rule saving command
  * diversion: Add type hints
  * Remove obsolete pytest fixture
  * base: Remove hard dependency on gi
  * base: Add more unit tests
  * Introduce HIDAPI protocol
  * Fix warnings from automatic code inspections
  * ui/common: Introduce tests
  * settings: Add tests
  * settings_template: Introduce State enum
  * Replace action strings with constants
  * Remove factory wrapper classes
  * receiver: Remove hard dependency on base
  * device: Remove hard dependency on base
  * base: Add test for filter_products_of_interest
  * Add type hints and clean up
  * base: Add find_paired_node functions
  * base: Add find_paired_node functions
  * Fix about dialog
  * base_usb: Add external interface
  * ui/about: Use Model-View-Presenter pattern for testability
  * hidapi: Explicitly load hidapi/udev implementation
  * receiver: Remove hard dependency on hidapi
  * device: Remove hard dependency on hidapi
  * Test coverage: Fix keysyms to be visible (#9)
  * keysyms: Introduce tests for this package
  * keysymdef: Rename key symbols
  * Upload test coverage reports solely after merging
  * ui: augment pairing message for devices with multiple channels
  * solaar: Add type hints
  * base: Add type hints
  * Replace global sw_id with function call
  * base: Simplify receiver info retrieval
  * settings_template: Prepare removal of desktop_notifications dependency
  * Make ui/desktop_notifications testable
  * Rename ui/notify module to desktop notifications
  * Make lr/desktop_notifications testable
  * Rename lr/notify module to desktop_notifications
  * Add code coverage badge
  * Setup reports and upload codecov
  * Introduce test coverage threshold
  * Fix test coverage reporting
  * Simplify setup with pathlib
  * Clarify that fake hidpp is used
  * hidapi: Completely remove dependency on gi
  * Introduce hid_parser tests
  * logitech_receiver: Remove GDK dependency
  * Refactor: Remove all GDK dependencies from hidapi package
  * Refactor: Distinguish module from package
  * settings: allow unkonwn keys in Key rule conditions
  * docs: improve documentation for cli actions
  * device: cycle sw_id to better guard against duplication of messages
  * device: handle error return on root feature
  * Remove incomplete developer docs
  * Publish GitHub pages only on push to master
  * docs: add information about Onboard Profiles overriding some settings
  * doc: add wording to README.md that Solaar is not a device driver
  * i18n: Chinese translations in .desktop files (#2554)
  * Clean up imports (#2537)
  * device: handle unknown device kinds
  * docs: fix broken links to Solaar logo
  * po: Update zh_CN translation (#2541)
  * docs: Use mkdocs for public documentation (#2527)
  * Clean up setup.py (#2536)
  * docs: dead links in the AppStream file (#2539)
  * docs: Update about.py (#2535)
  * settings: finish change to new constants
  * hidapi: remove check on driver
  * cli: finish change to show.py for new constants
  * Introduce Enum BusID
  * Introduce constant for Logitech vendor ID
  * Introduce Enum for notification types
  * Improve base module
  * Remove unnecessary receiver info 'hid_driver'
  * Convert HIDPPNotification to dataclass
  * device: be defensive when converting battery status to string
  * Automatically detect packages in /lib
  * hid: Convert definition of HID registers to enum
  * Use double quotes for module level docstrings
  * Remove empty comment lines
  * solaar: clean up locale code
  * docs: update built-in rules
  * docs: Improve rules documentation
  * refactor: Creation of devices (#2493)
  * docs: Add headings to structure rules.md
  * Unify imports in logitech package
  * device: don't ping device when getting name or codename
  * Refactor: Use dataclasses and enums
  * Introduce Device protocol and type hints
  * Add typing_extensions dependency
  * hidpp10: Move independent functions to module level
  * Refactor: Use dataclasses and enums
  * Fix macOS compatibility and reenable CI tests
  * docs: Update README.md
  * docs: Add high-level graph of components
  * hidapi: Unify imports in hidapi package (#2487)
  * docs: Move screenshots into dedicated folder
  * po: Update French translation (for release 1.1.13)
  * Drop support for end-of-life Python 3.7
- Run pytest
- Some spec cleanup
* Sat May 11 2024 asn@cryptomilk.org
- Update to version 1.1.13:
  * release 1.1.13
  * po: update Russian translation
  * po: Update Polish translation
  * release 1.1.13rc1
  * solaar: fix bug in suspend and resume callback
  * settings: add choices universe for backlight setting
  * diversion: Add unit tests
  * diversion: Simplify and type hint
  * settings: get and use current host number for K375sFnSwap because of bug in firmware of MX Keys S
  * ui: fix bug with logo in about window
  * solaar: don't ping device just to get logging information
  * settings: optimize write for per-key lighting
  * settings: add and initialize per-key lighting to a special no-change value
  * hidapi: Remove Python 2 compatibility (#2460)
  * po: Update French translation (for release 1.1.12) (#2458)
  * Refactor rule loading for testability (#2456)
* Mon Apr 29 2024 asn@cryptomilk.org
- Update to version 1.1.12:
  * release 1.1.12
  * po: Update zh_TW Traditional Chinese translation
  * release 1.1.12rc2
  * device: check for existences of keys file before opening
  * po: update Russion translation and have all strings translated
  * po: update Russian translation (#2443)
  * dist: add included hid_parser to packages installed
  * po: Update Polish translation (#2439)
  * settings: improve label and description for LED zone settings
  * settings: add message about Onboard Profiles to LED Zone settings
  * device: initialize device registers to empty list
  * po: Update Polish translation (#2435)
  * release 1.1.12rc1
  * release 1.1.12rc1
  * solaar: use bluez dbus signals to disconnect and connect bluetooth devices
  * device: handle a different signal for onboard profiles directory in ROM
  * receiver: introduce small delay in getting pairing information to let receiver settle after pairing
  * tests: extend tests for device.py
  * device: fix bug found in testing
  * tests: expand tests for device.py
  * device: fix small bugs uncovered by testing
  * tests: expand tests for settings_templates
  * tests: extend testing of hidpp20
  * device: fix bugs in onboard profiles found during testing
  * tests: extend testing of hidpp20
  * device: fix bugs in hidpp20 found during testing
  * tests: extend device testing
  * tests: test GESTURES settings
  * tests: extend testing of hidpp20
  * Updated  Greek Translation
  * doc: add information about bad interaction between Bluez 5.73 and Solaar
  * tests: expand tests for settings_templates
  * device: better support for extended ajustable dpi
  * device: limited support for extended adjustable dpi
  * tests: remove unused code
  * tests: adjust imports to always import installed version
  * tests: test more settings
  * settings: remove unused code and fix but in EQUALIZER setting
  * settings: provide symbolic names for per-key lighting keys
  * tests: improve infrastructure for testing setting_templates
  * settings: implement and test per-key lighting
  * tests: check for Gtk initialization and don't run tests that depend on it
  * tests: test GUI pair_window
  * ui: refactor pair_window
  * tests: fix tests for RBG effects
  * settings: add in bit telling RGB effects changes to change ROM
  * ui: handle situation when read of a setting fails
  * settings: permit continuing when a read during pushing fails
  * tests: add tests for RGB EFFECTS settings
  * settings: add settings for RGB EFFECTS feature
  * settings: fix bug in LEDZoneSetting when effect is not implemented
  * device: add RGB EFFECTS feature version of LED COLOR EFFECTS data
  * tests: add tests for LEDEffect structures in hidpp20
  * device: handle BRIGHTNESS CONTROL notifications
  * settings: implement and test BRIGHTNESS_CONTROL
  * tests: expand tests for settings_templates
  * settings: fix small bugs found from testing
  * refactor: Manually improve f-string formatting
  * refactor: Use f-strings for more exceptions and log message
  * settings: patch to make python 3.7 happy
  * tests: expand tests for settings_templates
  * tests: use new test methods in test_hidpp20_simple
  * tests: add tests for setting_templates
  * settings: simple change to improve testability
  * device: use feature_request from the device everywhere in hidpp20
  * settings: fix bug in backlight 2 durations
  * tests: fix finding paired node in test_device
  * tests: use hidpp module in several test modules
  * tests: add tests for logitech_receiver device
  * ui: reduce deprecation warnings in ui
  * hidapi: remove deprecation warnings
  * tests: improve coverage of receiver.py
  * device: align init methods for all receiver classes
  * tests: use 3.7 type hint
  * tests: improve hidpp20 coverage
  * tests: fully cover hidpp10
  * device: fix bug in hidpp10 get_device_features
  * refactor: Use dataclass for TestByte
  * refactor: Split diversion rules into smaller modules
  * refactor: Make _populate_model a function
  * rules: allow sub-second delays in Later
  * device: remove unreachable code
  * device: fix bug in setting configuration cookie due to bad documentation
  * Add new end line
  * Add solaar pot generation
  * Add indonesian translations
  * tests: complete testing of common
  * tests: start coverage of complex structures in hidpp20
  * tests: expand coverage of hidpp20
  * tests: expand coverage of common
  * ruff: Apply single line import format
  * ruff: Force single line imports
  * Automatically upgrade strings to f-string
  * docs: document battery-icons=solaar option
  * receiver: delay device sending first messages
  * device: remove checks for status attributes
  * device: optimize some functions in FeaturesArray
  * device: fix bug in creating features array
  * cli: fix bug in building battery line in show
  * ui: refactor diversion_rules
  * ui: fix bug in determining tray icon
  * device: fix bug in getting friendly name
  * device: remove status from Device and Receiver
  * device: move changed method from status to Device and Receiver
  * device: move link_encrypted from status to Device
  * device: move battery information from status to Device
  * device: move status string function to Device and Receiver
  * receiver: move pairing status to new dataclass attached to receiver
  * test: Test base product information
  * Disable macOS tests until GitHub CI dependencies are fixed
  * Extend Ubuntu dependencies for GitHub CI
  * test: Extract get_kind_from_index function and test it
  * docs: update EX100 information
  * device: use Python 3.7 type hints
  * device: use status attribute for error
  * device: use status attribute for notification_flags
  * device: use status attribute for link_encrypted
  * ui: use Battery object in GUI
  * device: change status battery fields to Battery objects
  * receiver: move more method code to subclasses
  * receiver: create subclasses of receiver for different variants
  * docs: add requirement for CONFIG_HIDRAW
  * tests: tests for a few simple hidpp20 functions
  * tests: add yaml test for led setting
  * tests: simple tests for hidpp20 profiles and lighting
  * ui: fix app name casing in UI
  * device: add missing receiver type for Lightspeed receivers
  * device: add new device types
  * refactor: Get receiver product info before instantiation
  * Refactor: Move Device instantiation to factory class
  * Refactor: Move Receiver instantiation to factory class
  * Simplify name of license file
  * Rename changelog.md to all capitals
  * Update .gitignore
  * Remove unused .gitmodules
  * fix: Use exception from exception module
  * update: Replace legacy logger.warn with logger.warning
  * cleanup: Remove duplicated code to read register
  * tests: Add hidpp10 tests
  * refactor: Introduce Hidpp20 class
  * refactor: Introduce Hidpp10 class
  * cleanup: Remove unnecessary calls of del
  * settings: fix bug when reading BACKLIGHT setting from device
  * clean up: Remove editor specific marks
  * fix: Replace invalid hidpp20 usage
  * fix: Replace invalid hidpp10 usage
  * solaar: use only timer thread to save config.yaml
  * docs: improve README.md
  * doc: Add link to Debian package to README.md
  * docs: adjust image placing in README
  * docs: adjust image size in README
  * docs: improve README
  * hid: copy newer version of hid_parser into Solaar codebase
  * ui: fix bug when displaying receiver notification flags
  * device: reorder code in settings
  * doc: update installation documentation
  * hidapi: make hid_parser optional, but add it to setup
  * device: add missing license blocks
  * device: clean up listener and notifications code
  * solaar: cleanup listener code
  * solaar: add locks to prevent multiple persisters for device
  * solaar: clean up configuration code
  * device: clean up device and receiver code
  * device: move battery constants common to HID++ 1.0 and 2.0 to common
  * device: move mapping of device kind into hidpp20
  * device: move pairing information gathering to receiver
  * docs: update contributors
  * solaar: fix debugging levels
  * device: expand allowable profile numbers
  * device: clean up __init__ in logitech_receiver
  * dist: modify pre-commit args to make ruff change files
  * device: fix bug in hidpp20 get host names
  * device: fix typo
  * Remove yapf exclusions
  * Manually fix linter issues
  * Apply ruff format
  * Makefile: Add command for formatting and linting
  * Introduce ruff formatter and linter
  * rules: fix bug in Set action
  * device: add notify module to logitech_receiver
  * ui: implement setting_changed callback and pass in to new devices and receivers
  * device: add callback to call when changing a setting
  * logitech_receiver: style fixes
  * logitech_receiver: Move hidpp20 constants into new module
  * logitech_receiver: Move hidpp10 constants into new module
  * logitech_receiver: Move exceptions into own module
  * device: streamline status code
  * hidapi: upgrade debugging in udev
  * dist: Fix deprecated GitHub actions
  * dist: extend makefile and tests
  * device: improve features array
  * ui: move ui_async to common.py
  * tests: Show pytest coverage in GitHub CI tests
  * device: improve imports in logitech_receiver
  * solaar: improve imports and guard Gtk, etc imports with correct version
  * ui: improve imports in ui
  * cli: move imports in __init__.py to top of file
  * device: improve imports in logitech_receiver
  * tests: Add tests of common module
* Wed Mar 20 2024 asn@cryptomilk.org
- Update to version 1.1.11:
  * release 1.1.11
  * dist: Add the <developer/> tag in the metainfo
  * dist: correctly find light icons
  * release 1.1.11rc4
  * dist: rename light icons and install them in correct place
  * macos: Remove dbus from macos dependencies
  * Setup macOS tests using GitHub action (#2284)
  * release 1.1.11rc3
  * ui: better checking for setting in record_setting
  * po: Update Polish translation (#2275)
  * Fix invalid func name set logo name
  * release 1.1.11rc2
  * udev: Simplify installation of udev rules
  * doc: add document on implementation
  * ui: tidy up scrolling appearance in configuration panel
  * device: correctly handle profile button with no action
  * ui: don't unlock setting when changed by external means
  * ui: refactor code to record change to setting
  * tests: Add GitHub action for tests
  * tests: Introduce tests with pytest
  * logging: Simplify logger instantiation
  * ui: update label and tooltip for divert-gkeys setting
  * ui: update label and tooltip for divert-gkeys setting
  * ui: don't lock setting when an error occurs
  * cli: catch assertion errors when reading setting values from devices
  * po: Update Polish translation (#2252)
  * release 1.1.11rc1
  * release 1.1.11rc1
  * device: remove dependency on webcolors
  * device: clean up data for LED effects
  * ui: better startup behavior for LED effect settings
  * ui: add UI for LED Zone control
  * device: add settings for LED Zone control
  * device: add structures for LED control
  * ui: add setting to change LED control between firmware and software
  * docs: document profiles
  * device: handle v4 of profiles data
  * device: better handing of unknown values in profiles
  * device: add version and device name to profiles
  * device: read profiles from ROM if none in Flash
  * device: decipher LED control info in profiles
  * cli: report more information on exception when loading profiles
  * ui: handle onboard profiles notifications
  * ui: upgrade onboard profiles setting to allow profile selection
  * device: support onboard profiles
  * device: remove extra debugging for backlight
  * ui: handle backlight notification
  * device: support backlight levels and duration
  * device: support bug in backlight on MX Keys S
  * cli: no numbers for USB and Bluetooth devices
  * devices: override name of Candy Companion Chip
  * po: Update RU language translation (#2242)
  * po: Mention language pack for Gnome in i18n.md (#2241)
  * ui: use Report Rate instead of Polling for movement report rate
  * device: add extended report rate setting
  * release: Add stable branch to release.sh (#2236)
  * release: fix changelog parsing in release.sh after d57af51316799252fdc67f575dc72d2568b3e48c (#2235)
  * docs: Update installation.md with new udev rules location (#2234)
  * ui: downgrade assertion on missing notification flag to warning
  * docs: add descriptions of G305 and MX Keys S
  * rules: write empty file if there are no rules to save
  * cli: be defensive in device error message
  * docs: add descriptions of M650 and PRO X 2
  * udev: report hidraw node in debugging messages
  * device: add names for new Logitech features
  * po: Spanish translation reviewed (#2209)
  * docs: add file for G915
  * gui: defend against lightspeed receivers that contact devices for basic information
  * docs: add files for MX Anywhere 2S and G915
  * device: remove incorrect feature for M325 mice
  * device: add K845 keyboard
  * rules: style fix
  * Partial support for macOS and Windows (#1971)
  * device: correctly enumerate devices on receiver
  * docs: add wording about Logitech reusing model numbers
  * ui: better handling and installation of icons
  * device: catch errors when pinging to try to put device online
  * ui: be more cautious when creating log messages to avoid exceptions
  * cli: handle NoSuchDevice exception when pinging device
  * rules: fix test for device equality
  * docs: add note about other GTK system packages
  * docs: add instructions for pipx
  * NamedInt: return False on comparison with None
  * device: add support for MK550
  * dist: install .rules to correct place by default
  * device: add connection request failed error to expected ping responses
  * ui: update codename when device status changes
  * doc: fix typos (#2152)
  * Update French translation (for release 1.1.10)
- Add missing dependency to typelib-AyatanaAppIndicator3
* Wed Oct 18 2023 Andreas Schneider <asn@cryptomilk.org>
- Add missing Require for dbus
* Mon Oct  2 2023 asn@cryptomilk.org
- Update to version 1.1.10:
  * release 1.1.10
  * pointer to NixOS flake package
  * release 1.1.10.rc3
  * release 1.1.10rc2
  * tools: permit BT devices for hidconsole with hidpp
  * device: add descriptor for Logitech MX Revolution Mouse M-RCL 124
  * device: allow return device 00 for BT device ff
  * device: improve determination of short or long messages
  * device: add descriptor for G500s
  * tools: fix bug in scan-registers
  * rules: add single depress and release options for rule mouse click action
  * rules: add rule condition for hostname
  * tools: update keysym generation to current list of keysyms
  * tools: allow device 0 in hidconsole
  * Update Arch repository name and link
  * doc: install recent version before opening issues
  * device: upgrade messages when no supported device found
  * Documentation update to mention the gnome extension to get rules working under Wayland (#2103)
  * Remove udev-acl tag from udev rules
  * Add support for process condition under wayland using solaar-gnome-extension (#2101)
  * Updated German Translation
  * po: update pot-file
  * po: Update zh_TW Traditional Chinese locale
  * hidapi: retry open several times with short wait to allow for delay in setting up permissions
  * Update French translation
  * Update French translation for 1.1.9 release
  * Update about.py
  * device: add new ID for G733 Headset
  * misc: restore tools/clean.sh
  * device: add bluetooth keyboard C714
  * tools: update scan-registers.sh to fix a bug and scan pairing registers
  * device: remove assertion on last byte of ping responses
  * ui: add symbolic version of solaar icon
  * docs: add description of several devices
  * device: add MX Vertical mouse (#2053)
  * device: when finding name or codename ping if not known to be online
  * device: fix bug in decoding G keys notification
  * docs: Standardise URLs and fix wording in i18n.md
  * docs: Fix wording in installation.md (#2040)
  * docs: Fix link and wording in devices.md (#2039)
  * docs: Add missing word in usage.md (#2038)
  * ui: put version in initial INFO logging message
  * ui: rearrange code in tray.py
- Ensure to only use one python version
* Tue Apr 11 2023 asn@cryptomilk.org
- Update to version 1.1.9:
  * device: add descriptior for EX110 keyboard
  * release 1.1.9rc2
  * device: Add support for G535 wireless gaming headset (#2034)
  * docs: Fix punctuation and language in rules.md (#2032)
  * po: updated greek translation (#2030)
  * Fix sentences and punctuation in features.md (#2029)
  * docs: Fix spelling and capitalisation in index.md (#2028)
  * Fix punctuation and wording in capabilities.md
  * Update Polish translation
  * release 1.1.9rc1
  * docs: add description for LIFT mouse
  * ui: remove deprecated GTK code
  * ui: zero exit code for kill interrupts
  * docs: update information about MX Master 3 for Business
  * rules: add Test condition for battery charging
  * doc: add description of G304 Lightspeed Wireless Gaming Mouse
  * device: get wpid for 28Mz devices from udev when enumerating
  * ui: add editing of Device rule condition
  * rules: add Device condition
  * docs: add Logi Pop Keys description
  * ui: don't show wireless link or battery information when unknown or not present
  * ui: online devices with no battery information probably don't have a battery
  * device: add desccriptor for G9x
  * receiver: fix bug in determining kind of devices for 27Mz receivers
  * device: add descriptor for LX7 mouse
  * doc: update documentation for EX100 receiver
  * doc: add description of Illuminated Keyboard with ID C318
  * ui: ignore smooth scroll settings by default
  * configuration: fix glitch when changing versions
  * rules: add more debugging output for rules
  * device: add descriptor for Illuminated Keyboard USB ID C318
  * device: clean up pinging code
  * device: put initial ping of direct-connected devices inside listener thread
  * settings: read and check before write for range settings
  * doc: update lightspeed receiver descriptions
  * ui: mention compatability and non-connection in pairing window
  * ui: improve determination of whether pairing possible
  * receiver: count found devices when enumerating them and cut off when all found
  * config: remove derived fields from config file when Solaar version changes
  * device: allow device descriptors without name and codename
  * ui: Filter and escape technical detail fields (#1953)
  * settings: add setting for ADC power management
  * docs: add description of G535 and N545
  * device: correctly determine whether to ping with a long HID++ message
  * device: add description for K470 keyboard from the MK470 combo (#1945)
  * docs: add setting value for mouse gestures
  * po: update German translation (#1940)
  * Update French translation for 1.1.8 release
  * tools: remove unnecessary clean.sh
  * tools: remove non-working monitor.py
  * ui: retry adding devices if permissions are wrong
  * ui: better handling of IO errors at device creation
  * ui: improve error pop-up for errors when creating devices
  * ui: add KeyIsDown to list of conditions
  * ui: allow editing of KeyIsDown conditions
  * docs: document KeyIsDown rule condition
  * rules: add KeyIsDown condition
  * device: clean up device creation
  * receiver: clean up receiver creation
* Sun Dec 18 2022 asn@cryptomilk.org
- Update to version 1.1.8:
  * release 1.1.8
  * docs: add description of G903
  * po: update Polish translation
  * release 1.1.8rc3
  * docs: document parameter for thumb wheel rule tests
  * ui: allow editing of rules with parameters
  * rules: add argument to thumb_wheel rules
  * po: fix name of Serbian translation file
  * Update Polish translation (#1920)
  * release 1.1.8rc2
  * release 1.1.8rc1
  * solaar: improve handling of wheel notifications
  * settings: only record changes of scroll wheel ratchet
  * settings: device errors don't eliminiate setting
  * device: more robust access to keyword exception fields
  * device: add support for config change feature
  * solaar: clean up gtk code
  * docs: add known issue with other device controllers
  * docs: update mouse gestures rules documentation
  * dist: update flake8 version
  * solaar: fix tyop in ping_all
  * dist: get Ubuntu version from dpkg-parsechangelog
  * dist: get Ubuntu version from dpkg-parsechangelog
  * dist: get Ubuntu version from dpkg-parsechangelog
  * dist: get Ubuntu version from dpkg-parsechangelog
  * dist: get Ubuntu version from dpkg-parsechangelog
  * misc: update .pre-commit-config.yaml (#1891)
  * misc: update yapf version
  * misc: update isort to current version
  * dist: get Ubuntu version from dpkg-parsechangelog
  * dist: print Ubuntu PPA environment
  * dist: get commit from Ubuntu PPA directory name if no git information
  * dist: update pre-commit versions and python version
  * dist: use separate data files for version and commit information
  * Update about.py (Spanish)
  * dist: use git describe to get git version information
  * dist: fix flake8 URL
  * docs: update installation instructions
  * dist: add 8-character commit hash to version information
  * dist: update solaar.desktop (#1857)
  * dist: get release in setup.py by reading lib/solaar/__init__.py
  * docs: remove version number from doc/_config.yml
  * Update es.po
  * misc: Update solaar.desktop (#1847)
  * po: Update es.po (#1846)
  * docs: update documentation on several devices
  * docs: update documentation on several devices
  * receiver: clarify status of C542 receiver
  * doc: update devices directory
  * receiver: show name of disconnecting receiver or device in disconnect warning
  * docs: add description of several devices
  * Fixed typo in capcbilities.md
  * ui: reduce standard size of rule editor window
  * install: remove unnecessary dependency on typing_extensions
* Thu Nov 10 2022 Andreas Schneider <asn@cryptomilk.org>
- Add require to python-hid-parser
* Thu Nov  3 2022 asn@cryptomilk.org
- Update to version 1.1.7:
  * install: add depdendency on typing_extensions
  * doc: add Wireless All-in-One Keyboard TK820
  * release 1.1.7rc2
  * relese 1.1.7rc2
  * cli: don't defer saves in cli and don't require gtk in cli
  * Update hr.po
  * Update Croatian translation
  * hidapi: be more permissive when recognizing HID++ report descriptors
  * po: update Polish translation
  * release 1.1.7rc1
  * settings: set minimum ratchet speed to 1, not 0
  * device: switch scroll ratcheting setting in response to scroll ratchet key notification
  * settings: add setting to turn scroll ratchet on and off
  * ui: eliminate visual glitch when updating range settings
  * solaar: make hid-parser an optional dependency
* Tue Oct 25 2022 asn@cryptomilk.org
- Update to version 1.1.6:
  * release 1.1.6
  * docs: mention that fn-swap is saved on some devices
  * docs: add Dell-branded mouse and keyboard
  * ui: only update remaining pairings after sucessful pairing
  * listener: check for presence of status attribute when resuming
  * Update Croatian translation
  * po: update Polish translation
* Thu Sep 15 2022 asn@cryptomilk.org
- Update to version 1.1.5:
  * release 1.1.5
  * docs: add several device descriptions
  * device: add G213 Prodigy Gaming Keyboard
  * po: Update Croatian translation (#1759)
  * po: update zh_CN translation
  * po: update Polish translation
  * chore: clean a redundant space in a UI label
  * release 1.1.5rc1
  * po: Turkish translate completed (#1752)
  * docs: move old device descriptions to new locations and fix up
  * settings: increase minimum stopped time betweeen mouse movements
  * rules: fix bug with non-recognized empty mouse movement
  * docs: fix typos in Solaar options documentation
  * ui: allow config panel to scroll
  * doc: descriptions for K360 4004 and MX Master 4071
  * doc: descriptions for Lightspeed Receiver C541 and G915 WIRELESS RGB Mechanical Gaming Keyboard 407E
  * ui: change security tooltip for unencrypted wireless connections
  * po: Norwegian Bokmal
  * doc: add known issue for key presses and changing hosts
  * docs: add known issue about diverted keys
  * docs: state that the Solaar GUI should run continously
  * cli: don't apply settings in solaar config
  * settings: move rawXY patch to new code for both sliding dpi and mouse gestures
  * ui: use device list in Active condition
  * ui: add description of rule components to rule editor
  * docs: add information on enhancement requests to add new devices
  * settings: ignore first movement for mouse gestures when reprog controls version is 5 or more
  * ui: add Active condition to rule editor
  * docs: document Active rule condition
  * rules: add rule condition to test whether a device is active
  * docs: update ERGO M575 Trackball 4096 description
  * docs: add Wireless Mobile Mouse MX Anywhere 2S 406A description
  * cli: terminate iteration over receiver devices when all have been found
  * rules: downgrade Set prolem messages from error to warning
  * ui: log informational messages and above to a temporary file
  * docs: add device information for ERGO M575 Trackball
  * ui: don't produce warnings when editing rules in rule editor
  * rules: save rules file even if there are no rules to save
  * docs: device documentation for MX Keys Keyboard and Wireless Mouse Pebble M350
  * device: get extended pairing information early and allow for unknown WPID
  * receiver: return null values if no pairing information available
  * receiver: use last_id as maximum device number not max_devices
  * cli: show more registers in solaar probe
  * docs: reflect change from json to yaml in capabilities documention
  * cli: show features versions in solaar show (#1709)
  * device: don't use field that may require communication with device in equality test
  * device: fix exception when removing device not in instance list
  * po: Use German word Gestentaste in translation
  * docs: update device documentation for MX Keys Mini and MX Master 3S
  * docs: update device directory documentation
  * docs: remove superceeded device documentation files
  * docs: update device documentation files
  * docs: new conventions for device documentation files
  * po: Added Serbian translation (#1687)
  * device: add desccriptor for G935 headset
  * device: add G502 Proteus Spectrum Optical Mouse
  * device: keep track of feature versions
  * po: update zh_TW translation (#1681)
  * rules: require gtk 3.0
  * rules: Fix circular import (#1673)
  * rules: find devices using method in Device
  * device: keep track of devices in list
  * po: update zh_CN translation
  * settings: convert old-style mouse gestures and dpi sliding settings to new style
  * docs: document changed Smart Shift and Mouse Gestures processing
  * settings: allow multiple keys for mouse gestures and dpi sliding
  * Fix release date in io.github.pwr_solaar.solaar.metainfo.xml
  * cli: explicitly save configuration at end of solaar config if no GUI running
  * configuration: defer configuration file writes for up to 5 seconds
  * device: use correct Solaar functions for unified and voltage battery functions
  * settings: defensive check for missing keys array in mouse gestures setting
  * device: compute approximate charge level for adc measurement feature
  * device: fix bugs in battery notification processing
  * ui: better presentation of battery information
  * device: add support for ADC MEASUREMENT battery feature
  * device: regularize and improve battery status gathering and reporting
  * doc: add information on how to find divertable key names in solaar show output
  * device: better warnings for feature call errors with reprogrammable key and gesture settings
  * ui: increase entry size for ChoiceControlBig
* Mon Jul  4 2022 asn@cryptomilk.org
- Update to version 1.1.4:
  * release 1.1.4
  * po: Update Croatian translation
  * po: Update Croatian translation
  * release 1.1.4rc2
  * settings: handle unusual values for persistent remappable action
  * settings: remove unused class variables
  * device: fix no-output values for persistent key mappings
  * doc: improve documentation on library needed for system tray integration
  * ui: remove blank lines from system tray popup
  * po: update Polish translation
* Mon May  9 2022 ecsos <ecsos@opensuse.org>
- Added python-dataclasses again. Without dataclasses solaar does
  not run under Leap.
  And python 3.6 is not deprecated in Leap 15.3 and 15.4.
  Suse support only python 3.6 as standard in Leap.
* Mon May  9 2022 Andreas Schneider <asn@cryptomilk.org>
- Drop python3-dataclasses which is only needed for Pyhton 3.6 and
  upstream doesn't support that python version anymore.
* Sat May  7 2022 ecsos <ecsos@opensuse.org>
- Fix needed dependencies.
- Run spec-cleaner.
* Mon May  2 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.3:
  * Update documentation files
  * Lower remove python 3.7 constructs and lower python dependency to 3.6
  * Fix bug in xtest mouse scrolling
  * Allow mouse gesture setting for non-mice, e.g., trackballs
  * Print message when there is another Solaar process running
  * Fix determination of whether to force read before writing boolean setting
  * Add recent diversion features to default list in rules UI
  * Add setting to divert hires scroll wheel
  * Don't use device kind to determine how to handle notifications
  * Update Polish, Russian, and zh_CN translations
  * Remove pggettext so as to not require Python 3.8
  * Remove Python 2 unicode support
  * Store keys in configuration file as int instead of str
  * Use yaml for configuration file instead of json.
  * Remove process-dependent rules from built-in rules.
  * Handle situation where GTK application cannot be set up in CLI.
  * Remove obsolete upower signals.
  * Appinfo/metadata fixes including using correct APP_ID.
  * Fix bugs in solaar config.
  * Add full set of mouse buttons in persistent remappable actions setting.
  * Improve rule behaviour under Wayland and when Xtest or X11 not available.
  * Fix up and document dependencies (evdev, Python, ...).
* Wed Mar 30 2022 Andreas Schneider <asn@cryptomilk.org>
- Add missing requirements
- Use python macros in spec file
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.2:
  * Update documentation on supported devices and translations
  * Include evdev as a dependency
  * Try to use uinput for fake input if XTest extension not available
  * Add Nano receiver C542 for M190 mice
  * Broaden range of HID++ Bluetooth devices
  * Add setting to divert gestures
  * Rule editor can edit all rule components
  * Configuation via solaar config takes effect in Solaar UI if it is running
  * Add setting to disable Onboard Profiles and decouple from Polling Rate setting
  * Add setting for PERSISTENT_REMAPPABLE_ACTION, common keyboard and mouse cases only
  * Split Test rule condition into Test and TestBytes and support in rule editor
  * Fix bug in speed-change setting
  * Support Backlight3 feature
  * Ensure that settings are pushed in resume
  * Update German, Polish, and zh_CN translations
  * Determine device number for direct-connected devices from protocol
  * fix bug in add and delete button actions in rule editor
  * dispose of no-op notifications quickly
  * add rule condition for checking device settings
  * use local file for conversion from key names to keysyms
  * get keyboard group and use to get correct keycodes (X11 only)
  * improve how rules work under Wayland
  * add settings for M-Key LEDs and MR-Key LED
  * fix bug in unpacking M and MR key notification
  * add G815 keyboard and MX518 mouse
  * add new special keys for recent keyboards
  * track M and MR keys for use in rules
  * make sure that device is online when searching for devices in solaar show
  * don't check for device kind in dpi sliding setting
  * fix problem with devices that report 0 DPI
  * handle missing divert-setting in action RW for settings
  * add id property (unitId or serial) and don't use ? for unknown serial
  * fix contains for NamedInts and eliminate use of has_element
  * check for xtest and disable modifier checking if not available
  * improve determination of gesture information
  * add Set rules to rule GUI
  * add gesture params to Set rules
  * hide system tray when there are no devices to control
  * add G733 headset, G9 mouse, G502 Hero mouse
  * Use greyscale solaar icon in tray when using symbolic icons
  * Fix bugs in solaar config
  * Use classes for settings to hep with modularity
  * Accept '~' and Toggle for toggling boolean settings in cli and rules
  * handle errors when writing to devices
  * refactor config_panel.py to use classes for widgets
  * add rules action to set Solaar settings
  * decrease amount of logging at each debug level
  * don't stretch toggles in settings
  * use key structure for key remapping setting
  * optimize ReprogrammableKey implementation
  * keep track of settings that are absent from device
  * add G512 keyboard and G402 mouse
  * reformat descriptors.py
  * use feature numbers for reprogrammable key versions
  * don't use new_from_icon_set in menu as it is deprecated
* Wed Dec 29 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.1.1
  * Keep left pane in Solaar main window the same size
  * Fix crash when checking a process condition when X11 not
    running
  * Add version number to output of solaar show
  * Fix crash when pinging a device with unknown protocol
  * Display battery percentage estimates from battery voltage
  * Add minimal support for Logitech PRO X Wireless Gaming
    Headset
  * Push settings when device requests software reconfiguration
  * Fix read for key/button diversion setting
  * Add modalias information to Solaar metainfo
  * Don't do on-screen notifications when devices are powered on
  * Add setting to switch crown between smooth and ratchet
    scrolling
  * Add write_prefix_bytes argument to Boolean validator
  * Update Russian and Spanish translations
  * New shell script tools to help determine capabilities of
    receivers
  * Add special keys for MX Keys for Business and MX Keys Mini
  * Improve tray menu ordering
  * Add --tray-icon-size option to get around bugs in some tray
    implementations
* Sat Nov 27 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.0
  * https://github.com/pwr-Solaar/Solaar/blob/1.1.0/ChangeLog
- Add missing dependency to python3-PyYAML - bso#1193123
* Mon Oct 25 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.7
  * https://github.com/pwr-Solaar/Solaar/blob/1.0.7/ChangeLog
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.6:
  * Update sliding DPI to look for suitable keys
  * Add mouse gestures that can trigger rules
  * Complain if receivers do not support connection notification
  * In polling rate setting, only modify onboard profiles when actually writing polling rate
  * Add ability to ignore settings.
  * Use symbols for receiver sub-registers
  * Add support for wired G700
  * Do not set attention icon
  * Replace deprecated GTK stock menu icons
  * Better handling of icons in tray and tray menus
  * Receiver c52e does not unpair
  * Match active WM_CLASS as well as active process name in rules
  * Correctly set icon theme value when regular battery icons are not available
  * Handle exception when device is not available when device is being added
  * Perform initial activation of devices in listener threads
  * Keep track of serial numbers in the configuration file
  * Don't update settings for non-active devices
  * Set the current host name if not stored on the device
  * Add setting for SMART SHIFT ENHANCED feature
  * Don't unnecessarily use long messages for HID++ 1.0 commands
  * Correctly select choices in solaar config and use 1-origin addressing
  * Add quirk for G915 TKL keyboard because its host mode inteferes with its Fn keys
  * Show command outputs both saved and on-device settings
  * Update documentation
  * Fix bug in hidconsole
  * Update French translation
* Wed Jun  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix the %%doc files. README.md is a symlink to
  'docs/index.md'. Let's use this file directly.
* Sat Feb 27 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.5
  * Update documentation on devices forgetting settings.
  * Improve help messages
  * Fix bug in finding receiver to pair
  * Solaar config command can set keyed settings.
* Thu Oct 22 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.4
  * Support USB and BT connected devices that are not in descriptors.py
  * Use FRIENDLY NAME for codename if needed and available.
  * Extract manufacturer and product ID from Udev HID information.
  * Add Bluetooth and USB product IDs to device descriptors records.
  * Support Bluetooth-connected devices.
  * Add model ID and unit ID to device identification.
  * Support changing DPI by pressing DPI Switch button and sliding horizontally
  * Add device-specific notification handlers.
  * Add MX Vertical USB information.
  * Udev rule adds seat permissions for all Logitech devices.
  * Support USB-connected devices in GUI.
  * Make probe and config work for USB-connected devices.
  * Improve strings and display for settings.
  * Correctly handle non-unifying connection notifications.
  * Update GUI strings for several settings.
  * Better support for EX100 and devices that connect to it.
  * Partial support for feature GESTURE_2.
  * Simplify interface for settings.
  * Use DJ connection notifications to set device active status
  * Udev rule sets seat write permissions for hidraw nodes for device as well as receivers.
  * Handle USB devices that use HID++ protocol in CLI.
  * Use device hidraw nodes where possible.
  * Handle receivers with serial numbers that don't provide number of pairings.
  * Ignore exceptions when setting locale.
  * Correctly discover settings that share a name.
  * Don't show pop-up notifications at startup.
  * Keep battery voltage updated in GUI.
  * Add Portugese translation.
  * Update several translations.
  * Add Lightspeed receivers c545 and c541.
  * Reimplement REPROG_CONTROLS data structure.
* Mon Aug  3 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.3
  * Remove deprecated solaar-cli application.
  * Don't install udev or autostart files from python (or pip).
  * Solaar needs Python 3.6+ and probably needs kernel 5.2+
  * Handle exceptions on dynamic settings when device is not connected.
  * Fix inifinite loop on some low-level write errors
  * Add support for EX100 keyboard/mouse and receiver (046d:c517)
  * Add two settings for THUMB_WHEEL feature - inversion and reporting via HID++
  * Update German translation
  * Use REPORT RATE feature when available to determine polling rate.
  * Improve config command speed when not printing all settings
  * Improve config command handling and checking of arguments
  * Add setting for CHANGE_HOST feature
  * Add argument to settings for values that are not to persist
  * Add argument to settings to not wait for reply when writing a value to device
  * Add argument to not wait for reply from request to device
  * Add settings for MULTIPLATFORM and DUALPLATFORM features
  * Remove Logitech documents from documentation directory
  * Change config command to not read all settings when only printing or showing one
  * Display hosts info in 'solaar show' if device supports it
  * Remove non-working smooth-scrool from M510 v1
  * Add yapf and flake8 code style checks
  * Fix feature k375s Fn inversion
  * Update controls (keys and buttons) and tasks (actions)
  * Improved way to specify feature settings.
  * Don't abort on device notifications with unexpected device numbers, just warn.
  * Keep track of non-features so as not to ask device multiple times.
  * Implement KEYBOARD DISABLE KEYS feature.
  * Don't create notifications for DJ device activity reports.
  * Update a few special keys and actions.
  * Add keyed choice settings in configuration panel.
  * Support remappable keys from reprogrammable keys v4 feature.
  * Add setting class for keyed choice.
  * Only check for features once per device.
  * Use settings interface to show feature values in solaar show if no special code for feature.
  * Remove maximum window size.
  * Process battery voltage notifications.
  * Display battery voltage information in main window if regular battery information not available.
  * Show next battery level where available.
  * Update list of implemented features and provide information on how to implement features.
  * Add c53d as a Lightspeed receiver.
* Sat May 23 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.2
- Removed 0001-Fix-reading-and-storing-DPI-in-config-settings.patch
- Removed 0001-data-fix-icon-theme-for-battery-level.patch
- Removed 0005-notifications-fix-battery-status-notification-parsin.patch
* Thu Oct  3 2019 Andreas Schneider <asn@cryptomilk.org>
- Add missing Requries for python3-gobject-Gdk
* Wed Sep 18 2019 Andreas Schneider <asn@cryptomilk.org>
- Apply udev rules to existing devices
* Tue Sep 17 2019 Andreas Schneider <asn@cryptomilk.org>
- Fix icon theme for battery level
  + Added 0001-data-fix-icon-theme-for-battery-level.patch
- Fix battery status notifaction parsing
  + Added 0005-notifications-fix-battery-status-notification-parsin.patch
* Thu Aug 22 2019 Andreas Schneider <asn@cryptomilk.org>
- Add a conflict with solaar-cli to solar-udev
* Thu Aug  1 2019 Andreas Schneider <asn@cryptomilk.org>
- Fix reading and storing DPI settings
  + Added 0001-Fix-reading-and-storing-DPI-in-config-settings.patch
* Sat Jul 27 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.1:
  * Updated the repo url.
  * Fixed typo which was crashing the application.
  * Improved the HID write routine which was causing issues on some devices.
  * Fix non-unifying receivers in Linux 5.2.
  * Add new Lightspeed receiver (used in the G305)
- Updates from version 1.0.0:
  * First major release after 6 years
  * Support for a lot of new mice and keyboards
* Tue Jun 10 2014 dmitry_r@opensuse.org
- Disable autostart options in setup script
* Wed May  7 2014 dmitry_r@opensuse.org
- Split CLI to separate package
- Add runtime requirements
- Use original udev rules
* Tue Aug  6 2013 malcolmlewis@opensuse.org
- Updated to version 0.9.2:
  + Added support for hand detection on the K800.
  + Added support for V550 and V450 Nano.
  + Fixed side-scrolling wit the M705 Marathon.
  + Fixed identification of the T650 Touchpad.
  + Added internationalization support and romanian translation.
  + Polish translation courtesy of Adrian Piotrowicz.
- Updates from version 0.9.1:
  + When devices report a battery alert, only show the alert once.
  + Make sure devices in the window tree are sorted by registration
    index.
  + Added an autostart .desktop file.
  + Replaced single-instance code with GtkApplication.
  + Fixed indentification of the M505 mouse.
  + Fixed an occasional windowing layout bug with the C52F Nano
    Receiver.
- Updates from version 0.9.0:
  + New single-window UI.
  + Performance MX leds show the current battery charge.
  + Support the VX Nano mouse.
  + Faster and more accurate detection of devices.
  + If upower is accessible through DBus, handle suspend/resume.
  + Replaced Solaar icons with SVGs.
  + Running solaar-cli in parallel with solaar is now less likely
    to cause issues.
  + Bugfixes to saving and applying device settings.
  + Properly handle ^C when running in console.
* Thu Jun 27 2013 malcolmlewis@opensuse.org
- Initial build.
- Add 99-logitech-unifying-receiver.rules: openSUSE specific udev
  rule.
- Add solaar-fix-desktop-categories.patch: Fix desktop categories
  as per openSUSE desktop file specification.
